@@ -4,7 +4,7 @@ use crate::Scene;
 #[typetag::serde(tag = "system")]
 pub trait System {
     /** Tick the system */
-    fn tick(&self, _scene: &Scene) {}
+    fn tick(&self, _scene: &mut Scene) {}
     /** Handle game event */
     fn on_event(&self, _scene: &mut Scene, _tag: &str, _data: &dyn std::any::Any) {}
 }
